@@ -47,6 +47,7 @@ namespace Kate
   class MainWindow;
   class Plugin;
   class PluginView;
+  class PluginConfigPageInterface;
 }
 
 class KFileItem;
@@ -172,8 +173,8 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
     void dropEvent( QDropEvent * );
 
   public Q_SLOTS:
+    void slotFileClose();
     void slotFileQuit();
-    void slotFileQuitDelayed();
 
     /**
      * slots used for actions in the menus/toolbars
@@ -222,7 +223,7 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
     void statusBarToggled ();
 
   public:
-    void openUrl (const QString &name = 0L);
+    void openUrl (const QString &name = QString());
     QModelIndex modelIndexForDocument(KTextEditor::Document *document);
 
     QHash<Kate::Plugin*, Kate::PluginView*> &pluginViews ()
@@ -242,7 +243,7 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
   private Q_SLOTS:
     void slotUpdateHorizontalViewBar();
 
-    
+
   private Q_SLOTS:
     void showFileListPopup(const QPoint& pos);
   protected:
@@ -252,6 +253,7 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
     void slotDocumentCloseAll();
     void slotDocumentCloseOther();
     void slotDocumentCloseOther(KTextEditor::Document *document);
+    void slotDocumentCloseSelected(const QList<KTextEditor::Document*>&);
     void slotDocModified(KTextEditor::Document *document);
   private:
     static uint uniqueID;
@@ -313,6 +315,9 @@ class KateMainWindow : public KateMDI::MainWindow, virtual public KParts::PartBa
   private:
     static KateMwModOnHdDialog *s_modOnHdDialog;
 
+  public:
+    void showPluginConfigPage(Kate::PluginConfigPageInterface *configpageinterface,uint id);  
+
 };
 
 #endif
