@@ -79,7 +79,7 @@ QMimeData *KateViewDocumentProxyModel::mimeData(const QModelIndexList &indexes)
     if (index.isValid())
     {
       kDebug()<<"mimeData:"<<index;
-      stream << index.row() << index.column();
+      stream << index.row();
     }
   }
   mimeData->setData("application/x-kateviewdocumentproxymodel", encodedData);
@@ -113,15 +113,11 @@ bool KateViewDocumentProxyModel::dropMimeData(const QMimeData *data,
 #warning handle single item moves only for now;
 #endif
   int sourcerow;
-  int sourcecolumn;
   stream >> sourcerow;
-  stream >> sourcecolumn;
-  kDebug() << sourcerow << "/" << sourcecolumn;
+  kDebug() << sourcerow;
 
   int insertRowAt = row - ((sourcerow < row) ? 1 : 0);
 
-
-
   beginRemoveRows(parent, sourcerow, sourcerow);
 
   int sourceModelRow = m_mapToSource[sourcerow];
@@ -139,7 +135,7 @@ bool KateViewDocumentProxyModel::dropMimeData(const QMimeData *data,
   endRemoveRows();
 
    kDebug()<<sourcerow<<"/////"<<insertRowAt;
-// 
+//
     beginInsertRows(parent, insertRowAt, insertRowAt);
     m_mapToSource.insert(insertRowAt, sourceModelRow);
 
@@ -148,10 +144,10 @@ bool KateViewDocumentProxyModel::dropMimeData(const QMimeData *data,
       int tmp = m_mapToSource[i];
       m_mapFromSource[tmp] = i;
     }
-// 
+//
    kDebug()<<"m_mapFromSource"<<m_mapFromSource;
    kDebug()<<"m_mapToSource"<<m_mapToSource;
-// 
+//
     m_rowCountOffset++;
     endInsertRows();
     QModelIndex index = createIndex(insertRowAt, 0);
@@ -328,7 +324,7 @@ QVariant KateViewDocumentProxyModel::data ( const QModelIndex & index, int role
 QModelIndex KateViewDocumentProxyModel::mapFromSource ( const QModelIndex & sourceIndex ) const
 {
   if (!sourceIndex.isValid()) return QModelIndex();
-  return createIndex(m_mapFromSource[sourceIndex.row()], sourceIndex.column());
+  return createIndex(m_mapFromSource[sourceIndex.row()], 0);
 }
 
 QItemSelection KateViewDocumentProxyModel::mapSelectionFromSource ( const QItemSelection & sourceSelection ) const
@@ -345,12 +341,13 @@ QModelIndex KateViewDocumentProxyModel::mapToSource ( const QModelIndex & proxyI
 {
   if (!proxyIndex.isValid()) return QModelIndex();
   if (proxyIndex.row()>=m_mapToSource.count()) return QModelIndex();
-  return sourceModel()->index(m_mapToSource[proxyIndex.row()], proxyIndex.column(), QModelIndex());
+  return sourceModel()->index(m_mapToSource[proxyIndex.row()], 0, QModelIndex());
 }
 
 int KateViewDocumentProxyModel::columnCount ( const QModelIndex & parent) const
 {
-  return sourceModel()->columnCount(mapToSource(parent));
+  Q_UNUSED(parent)
+  return 1;
 }
 
 QModelIndex KateViewDocumentProxyModel::index ( int row, int column, const QModelIndex & parent) const
@@ -493,7 +490,7 @@ void KateViewDocumentProxyModel::slotRowsAboutToBeInserted ( const QModelIndex &
   {
     if (m_current.row() > start)
     {
-      m_current = createIndex(m_current.row() + insertedRange, m_current.column());
+      m_current = createIndex(m_current.row() + insertedRange, 0);
     }
   }
   updateBackgrounds(false);
@@ -506,19 +503,20 @@ void KateViewDocumentProxyModel::removeItemFromColoring(int row)
 //   kDebug(13001)<<row;
   QModelIndex removeit = mapToSource(createIndex(row, 0));
   m_editHistory.removeAll(removeit);
+
   // adjust all indices below 'row'
   for(int i = 0; i < m_editHistory.count(); ++i) {
-    QModelIndex idx = mapFromSource(m_editHistory[i]);
-    if(idx.row() > row)
-      m_editHistory[i] = mapToSource(createIndex(idx.row() - 1, row));
+    if (m_editHistory[i].row() >= removeit.row())
+      m_editHistory[i] = createIndex(m_editHistory[i].row() - 1, 0);
   }
-  m_viewHistory.removeAll(removeit);
+
   // adjust all indices below 'row'
+  m_viewHistory.removeAll(removeit);
   for(int i = 0; i < m_viewHistory.count(); ++i) {
-    QModelIndex idx = mapFromSource(m_viewHistory[i]);
-    if(idx.row() > row)
-      m_viewHistory[i] = mapToSource(createIndex(idx.row() - 1, row));
+    if (m_viewHistory[i].row() >= removeit.row())
+      m_viewHistory[i] = createIndex(m_viewHistory[i].row() - 1, 0);
   }
+
   updateBackgrounds(false);
 }
 
@@ -537,21 +535,20 @@ void KateViewDocumentProxyModel::slotRowsAboutToBeRemoved ( const QModelIndex &
 
     m_rowCountOffset--;
 
-    for (int i = 0, i2 = 0;i < m_mapToSource.count();i++)
+    m_mapToSource.removeAt(removeRow);
+    for (int i = 0; i < m_mapToSource.count(); i++)
     {
-      if (i == removeRow) continue;
-      int x = m_mapToSource[i];
-      m_mapToSource[i2] = (x > row) ? (x - 1) : x;
-      i2++;
+      const int currentRow = m_mapToSource[i];
+      if (currentRow > row) {
+        m_mapToSource[i] = currentRow - 1;
+      }
     }
 
-    m_mapToSource.removeLast();
-    m_mapFromSource.removeLast();
-
     foreach (int sr, m_mapToSource) kDebug()<<sr;
     kDebug()<<"**************";
 
-    for (int i = 0;i < m_mapToSource.count();i++)
+    m_mapFromSource.removeLast();
+    for (int i = 0; i < m_mapToSource.count(); i++)
     {
       int tmp = m_mapToSource[i];
       m_mapFromSource[tmp] = i;
@@ -634,9 +631,9 @@ void KateViewDocumentProxyModel::sort()
     {
       QMap<QString,int> sorted;
       foreach( int row, m_mapToSource ) {
-	QString key=data(sourceModel()->index(row, 0), m_sortRole).toString();
+        QString key=data(sourceModel()->index(row, 0), m_sortRole).toString();
         if (key.isEmpty()) key=QString("kate-internal-untitled:/%1").arg(row);
-	sorted.insert(key, m_mapToSource[row]);
+        sorted.insertMulti(key, m_mapToSource[row]);
       }
       m_mapToSource = sorted.values();
     }
