@@ -42,6 +42,7 @@
 #include <QMessageBox>
 #include <QtDBus/QDBusConnection>
 #include <QStatusBar>
+#include <QWhatsThis>
 
 #include "partselection.h"
 #include "functionselection.h"
@@ -49,7 +50,7 @@
 #include "stackbrowser.h"
 #include "tracedata.h"
 #include "config.h"
-#include "globalconfig.h"
+#include "globalguiconfig.h"
 #include "multiview.h"
 #include "callgraphview.h"
 #include "configdialog.h"
@@ -72,7 +73,7 @@ QCGTopLevel::QCGTopLevel()
 
     resetState();
 
-    GlobalConfig::config()->readOptions();
+    GlobalGUIConfig::config()->readOptions();
 
     createActions();
     createDocks();
@@ -417,6 +418,23 @@ void QCGTopLevel::createActions()
 	    this, SLOT(togglePercentage()));
     _percentageToggleAction->setChecked(GlobalConfig::showPercentage());
 
+    _hideTemplatesToggleAction = new QAction(QIcon(":/hidetemplates.png"),
+                                             tr("Shorten Templates"), this);
+    _hideTemplatesToggleAction->setCheckable(true);
+    _hideTemplatesToggleAction->setStatusTip(tr("Hide Template Parameters "
+                                                "in C++ Symbols"));
+    connect(_hideTemplatesToggleAction, SIGNAL(triggered(bool)),
+            this, SLOT(toggleHideTemplates()));
+    _hideTemplatesToggleAction->setChecked(GlobalConfig::hideTemplates());
+    hint = tr("<b>Hide Template Parameters in C++ Symbols</b>"
+              "<p>If this is switched on, every symbol displayed will have "
+              "any C++ template parameters hidden, just showing &lt;&gt; "
+              "instead of a potentially nested template parameter.</p>"
+              "<p>In this mode, you can hover the mouse pointer over the "
+              "activated symbol label to show a tooltip with the "
+              "unabbreviated symbol.</p>");
+    _hideTemplatesToggleAction->setWhatsThis(hint);
+
     _expandedToggleAction = new QAction(QIcon(":/move.png"),
 					tr("Relative to Parent"), this);
     _expandedToggleAction->setCheckable(true);
@@ -577,6 +595,7 @@ void QCGTopLevel::createMenu()
     viewMenu->addAction(_cyclesToggleAction);
     viewMenu->addAction(_percentageToggleAction);
     viewMenu->addAction(_expandedToggleAction);
+    viewMenu->addAction(_hideTemplatesToggleAction);
     viewMenu->addSeparator();
     viewMenu->addAction(_splittedToggleAction);
     viewMenu->addAction(_splitDirectionToggleAction);
@@ -593,6 +612,8 @@ void QCGTopLevel::createMenu()
     settingsMenu->addAction(_configureAction);
 
     QMenu* helpMenu = mBar->addMenu(tr("&Help"));
+    helpMenu->addAction(QWhatsThis::createAction(this));
+    helpMenu->addSeparator();
     helpMenu->addAction(_aboutAction);
     helpMenu->addAction(_aboutQtAction);
 }
@@ -609,6 +630,7 @@ void QCGTopLevel::createToolbar()
     tb->addAction(_cyclesToggleAction);
     tb->addAction(_percentageToggleAction);
     tb->addAction(_expandedToggleAction);
+    tb->addAction(_hideTemplatesToggleAction);
     tb->addSeparator();
 
     tb->addAction(_backAction);
@@ -623,7 +645,7 @@ void QCGTopLevel::createToolbar()
 void QCGTopLevel::about()
 {
     QString text, version;
-    version = QLatin1String("0.5.1");
+    version = QLatin1String("0.6");
     text = QString("<h3>QCachegrind %1</h3>").arg(version);
     text += tr("<p>QCachegrind is a graphical user interface for analysing "
 	      "profiling data, which helps in the performance optimization "
@@ -683,6 +705,7 @@ void QCGTopLevel::togglePercentage()
   setPercentage(_percentageToggleAction->isChecked());
 }
 
+
 void QCGTopLevel::setAbsoluteCost()
 {
   setPercentage(false);
@@ -707,6 +730,18 @@ void QCGTopLevel::setPercentage(bool show)
     _multiView->notifyChange(TraceItemView::configChanged);
 }
 
+void QCGTopLevel::toggleHideTemplates()
+{
+    bool show = _hideTemplatesToggleAction->isChecked();
+    if (GlobalConfig::hideTemplates() == show) return;
+    GlobalConfig::setHideTemplates(show);
+
+    _partSelection->notifyChange(TraceItemView::configChanged);
+    _stackSelection->refresh();
+    _functionSelection->notifyChange(TraceItemView::configChanged);
+    _multiView->notifyChange(TraceItemView::configChanged);
+}
+
 void QCGTopLevel::toggleExpanded()
 {
     bool show = _expandedToggleAction->isChecked();
@@ -756,7 +791,7 @@ void QCGTopLevel::loadTrace()
     QString file;
     file = QFileDialog::getOpenFileName(this,
 					tr("Open Callgrind Data"),
-					QString::null,
+					_lastFile,
 					tr("Callgrind Files (callgrind.*)"));
     loadTrace(file);
 }
@@ -764,6 +799,7 @@ void QCGTopLevel::loadTrace()
 void QCGTopLevel::loadTrace(QString file, bool addToRecentFiles)
 {
     if (file.isEmpty()) return;
+    _lastFile = file;
 
     if (_data && _data->parts().count()>0) {
 
@@ -802,7 +838,7 @@ void QCGTopLevel::addTrace()
     QString file;
     file = QFileDialog::getOpenFileName(this,
 					tr("Add Callgrind Data"),
-					QString::null,
+					_lastFile,
 					tr("Callgrind Files (callgrind.*)"));
     addTrace(file);
 }
@@ -811,6 +847,7 @@ void QCGTopLevel::addTrace()
 void QCGTopLevel::addTrace(QString file)
 {
     if (file.isEmpty()) return;
+    _lastFile = file;
 
     if (_data) {
 	_data->load(file);
@@ -1489,7 +1526,7 @@ void QCGTopLevel::restoreTraceSettings()
     // function not available any more.. try with "main"
       if (!setFunction("main")) {
 #if 1
-	_functionSelection->setTopFunction();
+	_functionSelection->selectTopFunction();
 #else
 	HighestCostList hc;
 	hc.clear(50);
@@ -1752,15 +1789,13 @@ void QCGTopLevel::partsHideSelectedSlot()
 {
   if (!_data) return;
 
-  TracePart* part;
   TracePartList newHidden, newActive;
-  TracePartList l = _data->parts();
-  for (part=l.first();part;part=l.next()) {
-    if ((_activeParts.findRef(part)>=0) ||
-        (_hiddenParts.findRef(part)>=0))
-      newHidden.append(part);
-    else
-      newActive.append(part);
+  foreach(TracePart* part, _data->parts()) {
+      if (_activeParts.contains(part) ||
+          _hiddenParts.contains(part))
+          newHidden.append(part);
+      else
+          newActive.append(part);
   }
 
   _hiddenParts = newHidden;
