@@ -18,18 +18,18 @@
 #ifndef CLASSINFOVIEW_H
 #define CLASSINFOVIEW_H
 
-#include <qwidget.h>
-#include <k3listview.h>
+#include <QWidget>
+#include <QTreeWidget>
 
 /**
   *@author Richard Dale
   */
 
-class ClassInfoView : public K3ListView  {
-   Q_OBJECT
+class ClassInfoView : public QTreeWidget  {
+  Q_OBJECT
 public: 
-   ClassInfoView(QWidget *parent=0, const char *name=0);
-   ~ClassInfoView();
+  ClassInfoView( QWidget *parent = 0 );
+  ~ClassInfoView();
 
   void buildList( QObject *o );
 
