@@ -426,6 +426,23 @@ QString Catalog::mimetype()
 
     return m_storage->mimetype();
 }
+
+QString Catalog::sourceLangCode() const
+{
+    if (KDE_ISUNLIKELY( !m_storage ))
+        return QString();
+
+    return m_storage->sourceLangCode();
+}
+
+QString Catalog::targetLangCode() const
+{
+    if (KDE_ISUNLIKELY( !m_storage ))
+        return QString();
+
+    return m_storage->targetLangCode();
+}
+
 //END STORAGE TRANSLATION
 
 //BEGIN OPEN/SAVE
@@ -580,9 +597,9 @@ bool Catalog::saveToUrl(KUrl url)
         nameChanged=true;
 
 
-    bool remote=url.isLocalFile();
+    bool remote=!url.isLocalFile();
     QFile* file;
-    if (KDE_ISUNLIKELY( !remote ))
+    if (KDE_ISUNLIKELY( remote ))
         file=new KTemporaryFile();
     else
     {
@@ -639,7 +656,10 @@ void Catalog::doAutoSave()
     if (KDE_ISUNLIKELY( !m_storage ))
         return;
     if (!d->_autoSave->open(QIODevice::WriteOnly))
+    {
+        emit signalFileAutoSaveFailed(d->_autoSave->fileName());
         return;
+    }
     qWarning()<<"doAutoSave"<<d->_autoSave->fileName();
     m_storage->save(d->_autoSave);
     d->_autoSave->close();
@@ -708,6 +728,11 @@ void Catalog::flushUpdateDBBuffer()
         //kWarning()<<"nothing to flush or new file opened";
         return;
     }
+    if (Project::instance()->targetLangCode()!=targetLangCode())
+    {
+        kWarning()<<"not updating because target languages don't match";
+        return;
+    }
     kWarning()<<"updating!!";
     int form=-1;
     if (isPlural(pos.entry))
