@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -44,7 +44,7 @@
  * this data was obtained by running GNUPluralForms()
  * on all languages KDE knows of
 **/
-#define NUM_LANG_WITH_INFO 39
+#define NUM_LANG_WITH_INFO 40
 static const char* langsWithPInfo[NUM_LANG_WITH_INFO]={
 "ar",
 "cs",
@@ -82,6 +82,7 @@ static const char* langsWithPInfo[NUM_LANG_WITH_INFO]={
 "sr",
 "sr@latin",
 "sv",
+"th",
 "tr",
 "uk",
 "vi"
@@ -106,7 +107,7 @@ static const char* pInfo[NUM_LANG_WITH_INFO]={
 "nplurals=3; plural=n==1 ? 0 : n==2 ? 1 : 2;",
 "nplurals=2; plural=(n != 1);",
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);",
-"nplurals=2; plural=(n != 1);",
+"nplurals=1; plural=0;",
 "nplurals=2; plural=(n != 1);",
 "nplurals=1; plural=0;",
 "nplurals=1; plural=0;",
@@ -125,6 +126,7 @@ static const char* pInfo[NUM_LANG_WITH_INFO]={
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);",
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);",
 "nplurals=2; plural=(n != 1);",
+"nplurals=1; plural=0;"
 "nplurals=1; plural=0;",
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);",
 "nplurals=1; plural=0;"
@@ -290,46 +292,64 @@ void updateHeader(QString& header,
     if (KDE_ISUNLIKELY( !found ))
         headerList.append(temp);
 
+    
     langCode=Project::instance()->isLoaded()?
              Project::instance()->langCode():
              Settings::defaultLangCode();
+    QString language; //initialized with preexisting value or later
+    QString mailingList; //initialized with preexisting value or later
 
-    KConfig lll("all_languages", KConfig::NoGlobals, "locale");
-    lll.setLocale("");
+    KConfig allLanguagesConfig("all_languages", KConfig::NoGlobals, "locale"); allLanguagesConfig.setLocale(QString());
+    QRegExp langTeamRegExp("^ *Language-Team:.*");
     for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
-        found=it->contains(QRegExp("^ *Language-Team:.*"));
+        found=it->contains(langTeamRegExp);
         if (found)
         {
             //really parse header
             QMap<QString,QString> map;
-            QStringList langlist = KGlobal::locale()->languageList();
-            foreach (const QString &myit, langlist)
+            foreach (const QString &runningLangCode, KGlobal::locale()->allLanguagesList())
             {
-                KConfigGroup cg(&lll, myit);
-                map[cg.readEntry("Name")]=myit;
+                KConfigGroup cg(&allLanguagesConfig, runningLangCode);
+                map[cg.readEntry("Name")]=runningLangCode;
             }
+            if (map.size()<16) //may be just "en_US" and ""
+                kWarning()<<"seems that all_languages file is missing (usually located under /usr/share/locale)";
 
-            QRegExp re("^ *Language-Team: *(.*) *<");
-            QString val;
-            if ((re.indexIn(*it) != -1) && (map.contains( val=re.cap(1).trimmed() )))
-                langCode=map.value(val);
+            QRegExp re("^ *Language-Team: *(.*) *<([^>]*)>");
+            if (re.indexIn(*it) != -1 )
+            {
+                if (map.contains( re.cap(1).trimmed() ))
+                {
+                    language=re.cap(1).trimmed();
+                    mailingList=re.cap(2).trimmed();
+                    langCode=map.value(language);                    
+                }
+            }
 
             ait=it;
         }
     }
 
-    //language=locale.languageCodeToName(d->_langCode);
-    KConfigGroup cg(&lll, langCode);
-    QString language=cg.readEntry("Name");
     if (language.isEmpty())
-        language=langCode;
+    {
+        //language=locale.languageCodeToName(d->_langCode);
+        KConfigGroup cg(&allLanguagesConfig, langCode);
+        language=cg.readEntry("Name");
+        if (language.isEmpty())
+            language=langCode;
+    }
 
-    temp="Language-Team: "+language;
-    if (Project::instance()->isLoaded())
-        temp+=" <"+Project::instance()->mailingList()+'>';
-    else
-        temp+=" <"+Settings::defaultMailingList()+'>';
+    if (mailingList.isEmpty())
+    {
+        if (Project::instance()->isLoaded())
+            mailingList=Project::instance()->mailingList();
+        else
+            mailingList=Settings::defaultMailingList();
+    }
+
+
+    temp="Language-Team: "+language+" <"+mailingList+'>';
     temp+="\\n";
 
     if (KDE_ISLIKELY( found ))
@@ -378,7 +398,7 @@ void updateHeader(QString& header,
         headerList.append(temp);
 
 
-    kDebug()<<"testing for GNUPluralForms";
+    //kDebug()<<"testing for GNUPluralForms";
     // update plural form header
     for ( it = headerList.begin(),found=false; it != headerList.end()&& !found; ++it )
         found=it->contains(QRegExp("^ *Plural-Forms:"));
