@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -28,7 +28,7 @@
 #include "tmtab.h"
 #include "prefs_lokalize.h"
 
-#define WEBQUERY_ENABLE
+// #define WEBQUERY_ENABLE
 
 #include "project.h"
 #include "projectmodel.h"
@@ -89,6 +89,7 @@ LokalizeMainWindow::LokalizeMainWindow()
     m_mdiArea->setViewMode(QMdiArea::TabbedView);
     m_mdiArea->setActivationOrder(QMdiArea::ActivationHistoryOrder);
     m_mdiArea->setDocumentMode(true);
+
     setCentralWidget(m_mdiArea);
     connect(m_mdiArea, SIGNAL(subWindowActivated(QMdiSubWindow*)),this,SLOT(slotSubWindowActivated(QMdiSubWindow*)));
     setupActions();
@@ -96,6 +97,7 @@ LokalizeMainWindow::LokalizeMainWindow()
      //prevent relayout of dockwidgets
     m_mdiArea->setOption(QMdiArea::DontMaximizeSubWindowOnActivation,true);
 
+    connect(Project::instance(), SIGNAL(configChanged()), this, SLOT(projectSettingsChanged()));
     showProjectOverview();
 
     QString tmp=" ";
@@ -448,8 +450,8 @@ void LokalizeMainWindow::setupActions()
     action = proj->addAction("project_configure",sc,SLOT(projectConfigure()));
     action->setText(i18nc("@action:inmenu","Configure project"));
 
-    action = proj->addAction("project_configure",sc,SLOT(projectConfigure()));
-    action->setText(i18nc("@action:inmenu","Configure project"));
+    action = proj->addAction("project_create",sc,SLOT(projectCreate()));
+    action->setText(i18nc("@action:inmenu","Create new project"));
 
     action = proj->addAction("project_open",this,SLOT(openProject()));
     action->setText(i18nc("@action:inmenu","Open project"));
@@ -458,7 +460,9 @@ void LokalizeMainWindow::setupActions()
     m_openRecentProjectAction=new KRecentFilesAction(i18nc("@action:inmenu","Open recent project"),this);
     action = proj->addAction("project_open_recent",m_openRecentProjectAction);
     connect(m_openRecentProjectAction,SIGNAL(urlSelected(KUrl)),this,SLOT(openProject(KUrl)));
-    connect(Project::instance(),SIGNAL(loaded()), this,SLOT(projectLoaded()));
+
+    //Qt::QueuedConnection: defer until event loop is running to eliminate QWidgetPrivate::showChildren(bool) startup crash
+    connect(Project::instance(),SIGNAL(loaded()), this,SLOT(projectLoaded()), Qt::QueuedConnection);
 
     setupGUI(Default,"lokalizemainwindowui.rc");
 
@@ -517,6 +521,7 @@ void LokalizeMainWindow::saveProperties(KConfigGroup& stateGroup)
 void LokalizeMainWindow::saveProjectState(KConfigGroup& stateGroup)
 {
     QList<QMdiSubWindow*> editors=m_mdiArea->subWindowList();
+    
     QStringList files;
     QStringList mergeFiles;
     QList<QByteArray> dockWidgets;
@@ -528,7 +533,7 @@ void LokalizeMainWindow::saveProjectState(KConfigGroup& stateGroup)
     while (--i>=0)
     {
         //if (editors.at(i)==m_projectSubWindow)
-        if (!qobject_cast<EditorTab*>(editors.at(i)->widget()))
+        if (!editors.at(i) || !qobject_cast<EditorTab*>(editors.at(i)->widget()))
             continue;
         if (editors.at(i)==activeSW)
             activeSWIndex=files.size();
@@ -564,6 +569,7 @@ void LokalizeMainWindow::saveProjectState(KConfigGroup& stateGroup)
             projectStateGroup.writeEntry("UnitsCount", w->unitsCount());
     }
 
+
     QString nameSpecifier=Project::instance()->path();
     if (!nameSpecifier.isEmpty()) nameSpecifier.prepend('-');
     KConfig* c=stateGroup.isValid()?stateGroup.config():&config;
@@ -580,25 +586,30 @@ void LokalizeMainWindow::readProperties(const KConfigGroup& stateGroup)
 
     QString path=stateGroup.readEntry("Project",QString());
     if (Project::instance()->isLoaded() || path.isEmpty())
-        projectLoaded(); //we weren't existing yet when the signal was emitted
+    {
+        //1. we weren't existing yet when the signal was emitted
+        //2. defer until event loop is running to eliminate QWidgetPrivate::showChildren(bool) startup crash
+        QTimer::singleShot(0, this, SLOT(projectLoaded()));
+    }
     else
         Project::instance()->load(path);
 }
 
 void LokalizeMainWindow::projectLoaded()
 {
-    kDebug()<<Project::instance()->path();
-    m_openRecentProjectAction->addUrl( KUrl::fromPath(Project::instance()->path()) );
+    QString projectPath=Project::instance()->path();
+    kDebug()<<projectPath;
+    m_openRecentProjectAction->addUrl( KUrl::fromPath(projectPath) );
 
     KConfig config;
 
-    QString nameSpecifier=Project::instance()->path();
+    QString nameSpecifier=projectPath;
     if (!nameSpecifier.isEmpty()) nameSpecifier.prepend('-');
     m_openRecentFileAction->loadEntries(KConfigGroup(&config,"RecentFiles"+nameSpecifier));
 
 
     //if project isn't loaded, still restore opened files from "State-"
-    KConfigGroup projectStateGroup(&config,"State-"+Project::instance()->path());
+    KConfigGroup projectStateGroup(&config,"State-"+projectPath);
 
     QStringList files;
     QStringList mergeFiles;
@@ -633,7 +644,7 @@ void LokalizeMainWindow::projectLoaded()
         dialog->setAttribute(Qt::WA_DeleteOnClose,true);
         dialog->showButton(KDialog::Ok,true);
         dialog->showButton(KDialog::Cancel,false);
-        KMessageBox::createKMessageBox(dialog, QIcon(), i18nc("@info","Error opening the following files:"), 
+        KMessageBox::createKMessageBox(dialog, QIcon(), i18nc("@info","Error opening the following files:"),
                 failedFiles, QString(), 0, KMessageBox::NoExec, QString(), QMessageBox::Warning);
         dialog->show();
     }
@@ -647,11 +658,15 @@ void LokalizeMainWindow::projectLoaded()
         QTimer::singleShot(0,this,SLOT(applyToBeActiveSubWindow()));
     }
 
-    setCaption(Project::instance()->projectID());
+    projectSettingsChanged();
 
     QTimer::singleShot(0,this,SLOT(loadProjectScripts()));
 }
 
+void LokalizeMainWindow::projectSettingsChanged()
+{
+    setCaption(Project::instance()->projectID());
+}
 
 
 //BEGIN DBus interface
@@ -783,17 +798,27 @@ void LokalizeMainWindow::registerDBusAdaptor()
 
 void LokalizeMainWindow::loadProjectScripts()
 {
+    qWarning()<<"loadProjectScripts() 1111"<<Project::instance()->poDir();
     if (m_projectScriptingPlugin)
     {
+        qWarning()<<"loadProjectScripts() 222";
         guiFactory()->removeClient(m_projectScriptingPlugin);
         delete m_projectScriptingPlugin;
     }
 
+    qWarning()<<"loadProjectScripts() 333";
     //a HACK to get new .rc files shown w/o requiring a restart
     m_projectScriptingPlugin=new ProjectScriptingPlugin(this,m_multiEditorAdaptor);
+
+    //guiFactory()->addClient(m_projectScriptingPlugin);
+    //guiFactory()->removeClient(m_projectScriptingPlugin);
+
     delete m_projectScriptingPlugin;
+    qWarning()<<"loadProjectScripts() 444";
     m_projectScriptingPlugin=new ProjectScriptingPlugin(this,m_multiEditorAdaptor);
+    qWarning()<<"loadProjectScripts() 555";
     guiFactory()->addClient(m_projectScriptingPlugin);
+    qWarning()<<"loadProjectScripts() 666";
 }
 
 int LokalizeMainWindow::lookupInTranslationMemory(DocPosition::Part part, const QString& text)
@@ -886,6 +911,7 @@ void MultiEditorAdaptor::setEditorTab(EditorTab* e)
 
 void MultiEditorAdaptor::handleParentDestroy(QObject* p)
 {
+    Q_UNUSED(p);
     kWarning()<<"avoiding destroying m_multiEditorAdaptor";
     setParent(0);
 }
