@@ -6,7 +6,7 @@
  *                                                                         *
  *   copyright (C) 2005                                                    *
  *   Richard Dale  <Richard_Dale@tipitina.demon.co.uk>                     *
- *   copyright (C) 2006-2009                                               *
+ *   copyright (C) 2006-2010                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -54,7 +54,7 @@ RubyCodeGenerator::~RubyCodeGenerator ( )
  * Return our language.
  * @return language identifier
  */
-Uml::Programming_Language RubyCodeGenerator::getLanguage()
+Uml::Programming_Language RubyCodeGenerator::language() const
 {
     return Uml::pl_Ruby;
 }
@@ -170,7 +170,7 @@ void RubyCodeGenerator::initFields()
  * Get list of reserved keywords.
  * @return the list of reserved keywords
  */
-const QStringList RubyCodeGenerator::reservedKeywords() const
+QStringList RubyCodeGenerator::reservedKeywords() const
 {
     static QStringList keywords;
 
