@@ -14,8 +14,6 @@
 // app includes
 #include "uml.h"
 #include "umldoc.h"
-#include "umllistview.h"
-#include "umllistviewitem.h"
 #include "umlobject.h"
 #include "package.h"
 #include "folder.h"
@@ -26,6 +24,7 @@
 #include "template.h"
 #include "association.h"
 #include "object_factory.h"
+#include "model_utils.h"
 
 // kde includes
 #include <kmessagebox.h>
@@ -67,26 +66,51 @@ bool bPutAtGlobalScope = false;
  */
 QStringList incPathList;
 
+/**
+ * Control whether an object which is newly created by createUMLObject()
+ * is put at the global scope.
+ *
+ * @param yesno  When set to false, the object is created at the scope
+ *               given by the parentPkg argument of createUMLObject().
+ */
 void putAtGlobalScope(bool yesno)
 {
     bPutAtGlobalScope = yesno;
 }
 
+/**
+ * Set a related classifier for creation of dependencies on template
+ * parameters in createUMLObject().
+ */
 void setRelatedClassifier(UMLClassifier *c)
 {
     gRelatedClassifier = c;
 }
 
+/**
+ * Control whether the creation methods solicit a new unique ID for the
+ * created object.
+ * By default, unique ID generation is turned on.
+ *
+ * @param yesno   False turns UID generation off, true turns it on.
+ */
 void assignUniqueIdOnCreation(bool yesno)
 {
     Object_Factory::assignUniqueIdOnCreation(yesno);
 }
 
+/**
+ * Returns whether the last createUMLObject() actually created
+ * a new object or just returned an existing one.
+ */
 bool newUMLObjectWasCreated()
 {
     return bNewUMLObjectWasCreated;
 }
 
+/**
+ * Strip comment lines of leading whitespace and stars.
+ */
 QString formatComment(const QString &comment)
 {
     if (comment.isEmpty())
@@ -95,7 +119,7 @@ QString formatComment(const QString &comment)
     QStringList lines = comment.split('\n');
     QString& first = lines.first();
     QRegExp wordex("\\w");
-    if (first.startsWith("/*")) {
+    if (first.startsWith(QLatin1String("/*"))) {
         int wordpos = wordex.indexIn(first);
         if (wordpos != -1)
             first = first.mid(wordpos);  // remove comment start
@@ -130,6 +154,9 @@ UMLObject* findUMLObject(QString name, Uml::Object_Type type)
 }
  */
 
+/**
+ * Find or create a document object.
+ */
 UMLObject *createUMLObject(Uml::Object_Type type,
                            const QString& inName,
                            UMLPackage *parentPkg,
@@ -193,9 +220,7 @@ UMLObject *createUMLObject(Uml::Object_Type type,
                     Uml::Object_Type ot = (wantNamespace == KMessageBox::Yes ? Uml::ot_Package : Uml::ot_Class);
                     o = Object_Factory::createUMLObject(ot, scopeName, parentPkg);
                     parentPkg = static_cast<UMLPackage*>(o);
-                    UMLListView *listView = UMLApp::app()->getListView();
-                    UMLListViewItem *lvitem = listView->findUMLObject(o);
-                    listView->setCurrentItem(lvitem);
+                    Model_Utils::treeViewSetCurrentItem(o);
                 }
                 // All scope qualified datatypes live in the global scope.
                 bPutAtGlobalScope = true;
@@ -280,12 +305,25 @@ UMLObject *createUMLObject(Uml::Object_Type type,
     return o;
 }
 
+/**
+ * Create a UMLOperation.
+ * The reason for this method is to not generate any Qt signals.
+ * Instead, these are generated by insertMethod().
+ * (If we generated a creation signal prematurely, i.e. without
+ * the method parameters being known yet, then that would lead to
+ * a conflict with a pre-existing parameterless method of the same
+ * name.)
+ */
 UMLOperation* makeOperation(UMLClassifier *parent, const QString &name)
 {
     UMLOperation *op = Object_Factory::createOperation(parent, name);
     return op;
 }
 
+/**
+ * Create a UMLAttribute and insert it into the document.
+ * Use the specified existing attrType.
+ */
 UMLObject* insertAttribute(UMLClassifier *owner,
                            Uml::Visibility scope,
                            const QString& name,
@@ -295,9 +333,9 @@ UMLObject* insertAttribute(UMLClassifier *owner,
 {
     Uml::Object_Type ot = owner->getBaseType();
     Uml::Programming_Language pl = UMLApp::app()->getActiveLanguage();
-    if (! (ot == Uml::ot_Class || ot == Uml::ot_Interface && pl == Uml::pl_Java)) {
+    if (! (ot == Uml::ot_Class || (ot == Uml::ot_Interface && pl == Uml::pl_Java))) {
         uDebug() << "insertAttribute: Don not know what to do with "
-        << owner->getName() << " (object type " << ot << ")";
+                 << owner->getName() << " (object type " << ot << ")";
         return NULL;
     }
     UMLObject *o = owner->findChildObject(name, Uml::ot_Attribute);
@@ -316,6 +354,9 @@ UMLObject* insertAttribute(UMLClassifier *owner,
     return attr;
 }
 
+/**
+ * Create a UMLAttribute and insert it into the document.
+ */
 UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope,
                            const QString& name,
                            const QString& type,
@@ -335,6 +376,24 @@ UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility scope,
                             comment, isStatic);
 }
 
+/**
+  * Insert the UMLOperation into the given classifier.
+  *
+  * @param klass          The classifier into which the operation shall be added.
+  * @param op             Reference to pointer to the temporary UMLOperation
+  *                       for insertion.  The caller relinquishes ownership of the
+  *                       object pointed to.  If an UMLOperation of same signature
+  *                       already exists  at the classifier then the incoming
+  *                       UMLOperation is deleted and the pointer is set to the
+  *                       existing UMLOperation.
+  * @param scope          The Uml::Visibility of the method
+  * @param type           The return type
+  * @param isStatic       boolean switch to decide if method is static
+  * @param isAbstract     boolean switch to decide if method is abstract
+  * @param isFriend       true boolean switch to decide if methods is a friend function
+  * @param isConstructor  boolean switch to decide if methods is a constructor
+  * @param comment        The Documentation for this method
+  */
 void insertMethod(UMLClassifier *klass, UMLOperation* &op,
                   Uml::Visibility scope, const QString& type,
                   bool isStatic, bool isAbstract,
@@ -402,6 +461,11 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
     }
 }
 
+/**
+ * Add an argument to a UMLOperation.
+ * The parentPkg arg is only used for resolving possible scope
+ * prefixes in the `type'.
+ */
 UMLAttribute* addMethodParameter(UMLOperation *method,
                                  const QString& type,
                                  const QString& name)
@@ -420,12 +484,19 @@ UMLAttribute* addMethodParameter(UMLOperation *method,
     return attr;
 }
 
+/**
+ * Add an enum literal to an UMLEnum.
+ */
 void addEnumLiteral(UMLEnum *enumType, const QString &literal, const QString &comment)
 {
     UMLObject *el = enumType->addEnumLiteral(literal);
     el->setDoc(comment);
 }
 
+/**
+ * Create a generalization from the given child classifier to the given
+ * parent classifier.
+ */
 void createGeneralization(UMLClassifier *child, UMLClassifier *parent)
 {
     // if the child is an interface, so is the parent.
@@ -445,6 +516,10 @@ void createGeneralization(UMLClassifier *child, UMLClassifier *parent)
     umldoc->addAssociation(assoc);
 }
 
+/**
+ * Create a generalization from the existing child UMLObject to the given
+ * parent class name.
+ */
 void createGeneralization(UMLClassifier *child, const QString &parentName)
 {
     UMLObject *parentObj = createUMLObject( Uml::ot_Class, parentName );
@@ -452,6 +527,12 @@ void createGeneralization(UMLClassifier *child, const QString &parentName)
     createGeneralization(child, parent);
 }
 
+/**
+ * Return the list of paths set by previous calls to addIncludePath()
+ * and the environment variable UMBRELLO_INCPATH.
+ * This list can be used for finding included (or Ada with'ed or...)
+ * files.
+ */
 QStringList includePathList()
 {
     QStringList includePathList(incPathList);
@@ -462,12 +543,18 @@ QStringList includePathList()
     return includePathList;
 }
 
+/**
+ * Add a path to the include path list.
+ */
 void addIncludePath(const QString& path)
 {
     if (! incPathList.contains(path))
         incPathList.append(path);
 }
 
+/**
+ * Returns true if a type is an actual Datatype
+ */
 bool isDatatype(const QString& name, UMLPackage *parentPkg)
 {
     UMLDoc *umldoc = UMLApp::app()->getDocument();
